@@ -2,20 +2,27 @@
 """Json Bourne -- EZ-PZ-JSON with lots o goodies"""
 import keyword
 import sys
+
 from itertools import chain
 from pprint import pformat
-from typing import Any
-from typing import Dict
-from typing import ItemsView
-from typing import Iterable
-from typing import Iterator
-from typing import KeysView
-from typing import List
-from typing import Set
-from typing import Tuple
+from types import ModuleType
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    ItemsView,
+    Iterable,
+    Iterator,
+    KeysView,
+    List,
+    Optional,
+    Set,
+    Tuple,
+)
 
 from jsonbourne import json
 
+
 if sys.version_info < (3, 7):
     from collections.abc import MutableMapping
 
@@ -140,7 +147,7 @@ class JsonObj(JsonObjMutableMapping):
 
     """
 
-    def __init__(self, *args, **kwargs) -> None:
+    def __init__(self, *args: Any, **kwargs: Any) -> None:
         """Use the object dict"""
         self.__dict__.update(*args, **kwargs)
         try:
@@ -635,37 +642,7 @@ class JsonObj(JsonObjMutableMapping):
             JsonObj: JsonObj object for the given JSON string
 
         """
-        raise NotImplementedError
-
-    def to_json(self, pretty: bool = False, sort_keys: bool = False, **kwargs) -> str:
-        """Return a JSON string of the JsonObj object
-
-        Args:
-            minify (bool): Return a 'minified' version of the JSON string
-            sort_keys (bool): Sort the keys when converting to JSON
-            indent (int): Indent level of the json string
-            **kwargs: Keyword args to be passed on to the JSON dumps method
-
-        Returns:
-            str: JSON string of the JsonObj object
-
-        """
-        raise NotImplementedError
-
-    def stringify(self, pretty: bool = False, sort_keys: bool = False, **kwargs) -> str:
-        """Return a JSON string of the JsonObj; `JsonObj.to_json` alias
-
-        Args:
-            pretty (bool): If a 'minified' version of the JSON string
-            sort_keys (bool): Sort the keys when converting to JSON
-            **kwargs: Keyword args to be passed on to the JSON dumps method
-
-        Returns:
-            str: JSON string of the JsonObj object
-
-        """
-
-        return self.to_json(pretty=pretty, sort_keys=sort_keys, **kwargs)
+        return cls.from_json(json_string)
 
     @classmethod
     def _from_json(cls, json_string: str) -> "JsonObj":
@@ -680,7 +657,42 @@ class JsonObj(JsonObjMutableMapping):
         """
         return cls.from_dict(json.loads(json_string))
 
-    def _to_json(self, pretty: bool = False, sort_keys: bool = False, **kwargs) -> str:
+    def to_json(
+        self, pretty: bool = False, sort_keys: bool = False, **kwargs: Any
+    ) -> str:
+        """Return a JSON string of the JsonObj object
+
+        Args:
+            minify (bool): Return a 'minified' version of the JSON string
+            sort_keys (bool): Sort the keys when converting to JSON
+            indent (int): Indent level of the json string
+            **kwargs: Keyword args to be passed on to the JSON dumps method
+
+        Returns:
+            str: JSON string of the JsonObj object
+
+        """
+        return self._to_json(pretty=pretty, sort_keys=sort_keys, **kwargs)
+
+    def stringify(
+        self, pretty: bool = False, sort_keys: bool = False, **kwargs: Any
+    ) -> str:
+        """Return a JSON string of the JsonObj; `JsonObj.to_json` alias
+
+        Args:
+            pretty (bool): If a 'minified' version of the JSON string
+            sort_keys (bool): Sort the keys when converting to JSON
+            **kwargs: Keyword args to be passed on to the JSON dumps method
+
+        Returns:
+            str: JSON string of the JsonObj object
+
+        """
+        return self.to_json(pretty=pretty, sort_keys=sort_keys, **kwargs)
+
+    def _to_json(
+        self, pretty: bool = False, sort_keys: bool = False, **kwargs: Any
+    ) -> str:
         """Return a JSON string of the JsonObj object
 
         Args:
@@ -701,7 +713,7 @@ class JsonObj(JsonObjMutableMapping):
         return JsonObj(val)
 
     @classmethod
-    def __get_validators__(cls):
+    def __get_validators__(cls) -> Iterator[Callable[[Any], Any]]:
         """Return the JsonObj validator functions"""
         yield cls.validate_type
 
@@ -720,6 +732,13 @@ def jsonify(value: Any) -> Any:
         return [jsonify(el) for el in value]
     if isinstance(value, tuple):
         return tuple([jsonify(el) for el in value])
+    if isinstance(value, str):
+        try:
+            data = json.loads(value)
+            return jsonify(data)
+        except Exception:
+            pass
+
     return value
 
 
@@ -747,7 +766,11 @@ class JSON(metaclass=JSONMeta):
 
     @staticmethod
     def stringify(
-        data, pretty: bool = False, sort_keys=False, default=None, **kwargs
+        data: Any,
+        pretty: bool = False,
+        sort_keys: bool = False,
+        default: Optional[Callable[[Any], Any]] = None,
+        **kwargs: Any,
     ) -> str:
         return str(
             json.dumps(
@@ -757,7 +780,11 @@ class JSON(metaclass=JSONMeta):
 
     @staticmethod
     def dumps(
-        data, pretty: bool = False, sort_keys=False, default=None, **kwargs
+        data: Any,
+        pretty: bool = False,
+        sort_keys: bool = False,
+        default: Optional[Callable[[Any], Any]] = None,
+        **kwargs: Any,
     ) -> str:
         return str(
             json.dumps(
@@ -767,7 +794,11 @@ class JSON(metaclass=JSONMeta):
 
     @staticmethod
     def binify(
-        data, pretty: bool = False, sort_keys=False, default=None, **kwargs
+        data: Any,
+        pretty: bool = False,
+        sort_keys: bool = False,
+        default: Optional[Callable[[Any], Any]] = None,
+        **kwargs: Any,
     ) -> bytes:
         return bytes(
             json.dumpb(
@@ -777,7 +808,11 @@ class JSON(metaclass=JSONMeta):
 
     @staticmethod
     def dumpb(
-        data, pretty: bool = False, sort_keys=False, default=None, **kwargs
+        data: Any,
+        pretty: bool = False,
+        sort_keys: bool = False,
+        default: Optional[Callable[[Any], Any]] = None,
+        **kwargs: Any,
     ) -> bytes:
         return bytes(
             json.dumpb(
@@ -786,10 +821,10 @@ class JSON(metaclass=JSONMeta):
         )
 
     @staticmethod
-    def loads(string: str, obj: bool = False, **kwargs) -> Any:
+    def loads(string: str, obj: bool = False, **kwargs: Any) -> Any:
         if obj:
-            return jsonify(json.loads(string))
-        return json.loads(string)
+            return jsonify(json.loads(string, **kwargs))
+        return json.loads(string, **kwargs)
 
     @staticmethod
     def parse(string: str, obj: bool = True) -> Any:
@@ -797,6 +832,16 @@ class JSON(metaclass=JSONMeta):
             return jsonify(json.loads(string))
         return json.loads(string)
 
+    @staticmethod
+    def json_lib() -> Any:
+        return json._json.__class__.__name__
+
+
+class JSONModuleCls(ModuleType, JSON):
+    @staticmethod
+    def __call__(value: Any):  # type: ignore
+        return jsonify(value)
+
 
 stringify = JSON.stringify
 parse = JSON.parse
