@@ -1,11 +1,10 @@
 # -*- coding: utf-8 -*-
-from abc import ABC
-from abc import abstractmethod
-from datetime import datetime
-from datetime import timedelta
+from abc import ABC, abstractmethod
+from datetime import datetime, timedelta
 from decimal import Decimal
 from pathlib import Path
-from typing import Any
+from typing import Any, Callable, Optional
+
 
 try:
     import numpy as np
@@ -17,14 +16,22 @@ class JsonLib(ABC):
     @staticmethod
     @abstractmethod
     def dumps(
-        data: Any, pretty: bool = False, sort_keys: bool = False, default=None, **kwargs
+        data: Any,
+        pretty: bool = False,
+        sort_keys: bool = False,
+        default: Optional[Callable[[Any], Any]] = None,
+        **kwargs: Any,
     ) -> str:
         ...
 
     @staticmethod
     @abstractmethod
     def dumpb(
-        data: Any, pretty: bool = False, sort_keys: bool = False, default=None, **kwargs
+        data: Any,
+        pretty: bool = False,
+        sort_keys: bool = False,
+        default: Optional[Callable[[Any], Any]] = None,
+        **kwargs: Any,
     ) -> bytes:
         ...
 
